export default async function handler(req, res) {
  if (req.method !== 'POST') {
    return res.status(405).json({ error: 'Method not allowed' });
  }

  try {
    const { untrustedData, trustedData } = req.body;
    const fid = trustedData?.fid || 'Unknown';

    // Generate dynamic image with FID
    const imageUrl = `https://fcidframehub.pro/api/generate-image?fid=${fid}`;

    return res.status(200).json({
      version: 'vNext',
      image: {
        src: imageUrl,
        aspectRatio: '1.91:1'
      },
      buttons: [
        {
          label: 'Share My FID',
          action: 'post'
        }
      ]
    });
  } catch (error) {
    console.error('Frame API error:', error);
    return res.status(500).json({ error: 'Internal server error' });
  }
}
